/*
 *  connectnow home widget for the maemo desktop.
 *  Copyright (C) 2010 Nicolai Hess
 *  
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *  
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *  
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#ifndef CONNECTNOW_LOAD_AND_STORE_H
#define CONNECTNOW_LOAD_AND_STORE_H

#include <gtk/gtk.h>
#include "connectnow-home-widget.h"

static const int CONNECTNOW_DEFAULT_WIDGET_WIDTH = 96;
enum CONNECT_CHANGE_ACTION {
  NO_CHANGE = 0,
  CHANGE_TO_GSM,
  CHANGE_TO_3G
};

void 
read_settings(ConnectNowHomePlugin *desktop_plugin);

void
connect_now_save_settings(ConnectNowHomePlugin *desktop_plugin);

GdkPixbuf* 
load_image(const gchar* image_name);
#endif
